#!/usr/bin/env python

'''
Module Name:    op_install.py

Description:    Script to install the operational package into the target machine

Copyright:      Toshiba Confidential

                OCO Source Materials

                Copyright (C) 2012 Toshiba Global Commerce Solutions, Inc.

                The source code for this program is not published
                or otherwise divested of its trade secrets,
                irrespective of what has been deposited with the
                U. S. Copyright Office.

Initial Author: Francisco Liwa

Function:

Notes:

Dependencies:    None

Restrictions:    None

Created: November 5, 2012

'''


import os,sys,subprocess
import logging
import datetime

OP_LOG_FILE_DIR = '/var/log/toshiba/MonitorUpgrade/op_installation'
LOG_NAME = 'OP_INSTALL-v1.0.14'

    

#Create the logger object
logger = logging.getLogger(LOG_NAME)
logger.setLevel(logging.INFO)  

# make some handlers
date_now = datetime.datetime.now()
logname = LOG_NAME + '-' + str(date_now) + '.log'

name = os.path.join(OP_LOG_FILE_DIR,logname)
#print 'Logging to file '+ name
console_handler = logging.StreamHandler() # by default, sys.stderr
file_handler = logging.FileHandler(name)

# set logging levels
console_handler.setLevel(logging.WARNING)
file_handler.setLevel(logging.INFO)

# create formatter
formatter = logging.Formatter('%(asctime)s - %(name)s:[%(levelname)s] - %(message)s')

# add formatter to file_handler
file_handler.setFormatter(formatter)
console_handler.setFormatter(formatter)
  
# add handlers to logger
logger.addHandler(console_handler)
logger.addHandler(file_handler)      


#===============================================================================
# #method to run any shell commands from python
#===============================================================================
def runCmd(cmd):
    
    logger.info(cmd)   
    process = subprocess.Popen(cmd,shell=True, stdout=subprocess.PIPE)
    while True:
        line = process.stdout.readline()
        if not line:
            break
        logger.info(line)    
        #print line
    


#===============================================================================
# #Basically , just create the file system at the start and then
# #Register the Monitor Upgrade Services
#===============================================================================

print '\nStarting Monitor Upgrade Service installation...\n'
logger.info('Starting installation...')

print 'Checking dependencies...'
logger.info('Checking dependencies...')

#print 'lsmod | grep elo'
runCmd ('lsmod | grep elo')


print ('Extracting  ELO TOOLs...') 
logger.info('Extracting  ELO TOOLs...')
        
#print 'Extracting /opt/toshiba/MonitorUpgrade/op/4820/ELO/elo.tar...'
runCmd ('tar -C /opt/toshiba/MonitorUpgrade/op/4820/ELO/ -xvf  /opt/toshiba/MonitorUpgrade/op/4820/ELO/elo.tar')

#moving elo binaries to /usr/bin/

runCmd ('cp -p  /opt/toshiba/MonitorUpgrade/op/4820/ELO/elodownload /opt/toshiba/MonitorUpgrade/op/4820/ELO/eloconfig  /opt/toshiba/MonitorUpgrade/op/4820/ELO/Fw* /usr/bin/')
runCmd('chmod +x /usr/bin/elodownload /usr/bin/eloconfig')

#moving elo rules to /etc/udev/rules.d/

runCmd('cp -p /opt/toshiba/MonitorUpgrade/op/4820/ELO/11-elo.rules  /etc/udev/rules.d/')

print ('Extracting  SAMPO TOOLs...') 
logger.info('Extracting  SAMPO TOOLs...')

 #print 'Extracting /opt/toshiba/MonitorUpgrade/op/4820/SAMPO/sampo.tar...'
runCmd ('tar -C /opt/toshiba/MonitorUpgrade/op/4820/SAMPO/ -xvf /opt/toshiba/MonitorUpgrade/op/4820/SAMPO/sampo.tar')

print ('Extracting  License files...')
logger.info('Extracting License files...')
runCmd ('tar -C /opt/toshiba/MonitorUpgrade/LA/ -xvf /opt/toshiba/MonitorUpgrade/LA/LA.tar')

runCmd ('rm -rf /opt/toshiba/MonitorUpgrade/LA/LA.tar')

print 'Creating MUS directory...'
logger.info('Creating MUS directory...')

#print 'Checking directory -/opt/toshiba/MonitorUpgrade/mus/scripts/...'
logger.info('Checking directory -/opt/toshiba/MonitorUpgrade/mus/scripts/...')

#===============================================================================
# #Let's create the scripts directory first
# #This is where we place are soft-links of python scripts
#===============================================================================
if os.path.exists('/opt/toshiba/MonitorUpgrade/mus/scripts/'):
        
        #print '/opt/toshiba/MonitorUpgrade/mus/scripts/  exist!'
        logger.info('/opt/toshiba/MonitorUpgrade/mus/scripts/ exist!')
       
        print ('Creating scripts directories...') 
        logger.info('Creating scripts directories')
        
        #print 'mkdir /opt/toshiba/MonitorUpgrade/mus/scripts/initscript'
        runCmd ('mkdir /opt/toshiba/MonitorUpgrade/mus/scripts/init')
        
        #print 'mkdir /opt/toshiba/MonitorUpgrade/mus/scripts/monitorupgrade'
        runCmd ('mkdir /opt/toshiba/MonitorUpgrade/mus/scripts/monitorupgrade')
        
print 'Creating soft-link to scripts...'
logger.info('Creating soft-link to scripts...')

#===============================================================================
# Creating link from the site-packages to our file-system
# This will make sure that during execution, our python scripts will work because 
# they will not be looking for things inside the site-packages directory but instead 
# in our own file system
#===============================================================================
    
print 'Linking init scripts...'
runCmd ('ln -sf /usr/local/lib/python2.6/site-packages/init/* /opt/toshiba/MonitorUpgrade/mus/scripts/init/')

print 'Linking monitorupgrade...'
runCmd ('ln -sf /usr/local/lib/python2.6/site-packages/monitorupgrade/* /opt/toshiba/MonitorUpgrade/mus/scripts/monitorupgrade/')


#===============================================================================
# #Create a copy of our service to /etc/init.d`
# #This will enable our script to be invoke during boot up of the machine
# #Note: MUST make sure the copy in the /etc/init.d should not have the extension 
# ".py" or else this won't work
#===============================================================================
#print 'Adding init script to /etc/init.d/...'
logger.info('Adding init script to /etc/init.d/...')

#print 'Copying MonitorUpgradeSvc...'
runCmd('cp -p /usr/local/lib/python2.6/site-packages/initscript/MonitorUpgradeSvc.py /etc/init.d/MonitorUpgradeSvc')


#===============================================================================
# #Now Register the service using chkconfig
# #Opted to use this method instead of insserv,
# #They pretty much do the same function
#===============================================================================

runCmd('chmod +x /etc/init.d/MonitorUpgradeSvc')
#runCmd('chown root:root /etc/init.d/MonitorUpgradeSvc')

print 'Registering MonitorUpgradeSvc...'
logger.info('Registering MonitorUpgradeSvc...')

runCmd('chkconfig -a MonitorUpgradeSvc')
runCmd('chkconfig MonitorUpgradeSvc on')


#===============================================================================
# #DONE!
#===============================================================================
print '\nInstallation Complete!\n'
logger.info('Installation Complete!')
